@@ -2,7 +2,6 @@
 #  SPDX-License-Identifier: Apache-2.0
 
 import functools
-import json
 from servicecatalog_puppet import serialisation_utils
 import logging
 import os
@@ -268,5 +267,26 @@ def get_scheduler_threads_or_processes():
     )
 
 
+def get_scheduler_algorithm():
+    return os.environ.get(
+        environmental_variables.SCHEDULER_ALGORITHM,
+        constants.SCHEDULER_ALGORITHM_DEFAULT,
+    )
+
+
 def get_reporting_role_arn(puppet_account_id):
     return get_role_arn(puppet_account_id, constants.REPORTING_ROLE_NAME)
+
+
+def get_spoke_scheduler_threads_or_processes():
+    return os.environ.get(
+        environmental_variables.SPOKE_SCHEDULER_THREADS_OR_PROCESSES,
+        constants.SPOKE_SCHEDULER_THREADS_OR_PROCESSES_DEFAULT,
+    )
+
+
+def get_spoke_scheduler_algorithm():
+    return os.environ.get(
+        environmental_variables.SPOKE_SCHEDULER_ALGORITHM,
+        constants.SPOKE_SCHEDULER_ALGORITHM_DEFAULT,
+    )
