@@ -385,3 +385,8 @@ REPORTING_ROLE_NAME = "PuppetRoleForReporting"
 SHARE_PRINCIPALS_DEFAULT = False
 
 DESCRIBE_PORTFOLIO_SHARES = "describe-portfolio-shares"
+
+
+SCHEDULER_ALGORITHM_DEFAULT = "topological_generations"
+SPOKE_SCHEDULER_THREADS_OR_PROCESSES_DEFAULT = SCHEDULER_THREADS_OR_PROCESSES_DEFAULT
+SPOKE_SCHEDULER_ALGORITHM_DEFAULT = SCHEDULER_ALGORITHM_DEFAULT
