@@ -23,4 +23,7 @@ GLOBAL_SHARE_TAG_OPTIONS = "SCT_GLOBAL_SHARE_TAG_OPTIONS"
 ON_COMPLETE_URL = "SCT_ON_COMPLETE_URL"
 SPOKE_EXECUTION_MODE_DEPLOY_ENV = "SCT_SPOKE_EXECUTION_MODE_DEPLOY_ENV"
 SCHEDULER_THREADS_OR_PROCESSES = "SCT_SCHEDULER_THREADS_OR_PROCESSES"
+SCHEDULER_ALGORITHM = "SCT_SCHEDULER_ALGORITHM"
+SPOKE_SCHEDULER_THREADS_OR_PROCESSES = "SCT_SPOKE_SCHEDULER_THREADS_OR_PROCESSES"
+SPOKE_SCHEDULER_ALGORITHM = "SCT_SPOKE_SCHEDULER_ALGORITHM"
 GLOBAL_SHARE_PRINCIPALS = "SCT_GLOBAL_SHARE_PRINCIPALS"
